@@ -245,6 +245,7 @@ func main() {
 	)
 
 	go func() {
+		firstOk := false
 		for {
 			node, err := parser.Parse()
 			if err != nil {
@@ -257,8 +258,13 @@ func main() {
 					break
 				}
 				textNode := parser.Recover()
+				if !firstOk && !strings.HasPrefix(textNode.Value, "HTTP") {
+					p.Send(errorMsg{err: err})
+					break
+				}
 				p.Send(nodeMsg{node: textNode})
 			} else {
+				firstOk = true
 				p.Send(nodeMsg{node: node})
 			}
 		}
@@ -269,12 +275,12 @@ func main() {
 		panic(err)
 	}
 
-	if m.printOnExit {
-		fmt.Println(m.cursorValue())
-	}
-
 	if m.printErrorOnExit != nil {
-		fmt.Print(m.printErrorOnExit.Error())
+		fmt.Println(m.printErrorOnExit.Error())
+	} else if m.printOnExit {
+		fmt.Println(m.cursorValue())
+	} else {
+		exit()
 	}
 }
 
@@ -1205,6 +1211,7 @@ func (m *model) selectNode(n *Node) {
 		m.cursor = 0
 		m.head = n
 		m.scrollIntoView()
+		m.centerLine(n)
 	}
 	parent := n.Parent
 	for parent != nil {
