@@ -208,3 +208,13 @@ func (m *model) View() string {
 
 	return string(screen)
 }
+
+func (m *model) centerLine(n *Node) {
+	middle := m.visibleLines() / 2
+
+	for range middle {
+		m.up()
+	}
+
+	m.selectNodeInView(n)
+}
